vfbLib.compilers.glyph.MaskCompiler
===================================

.. currentmodule:: vfbLib.compilers.glyph

.. autoclass:: MaskCompiler
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MaskCompiler.__init__
      ~MaskCompiler.compile
      ~MaskCompiler.compile_hex
      ~MaskCompiler.compile_outlines
      ~MaskCompiler.merge
      ~MaskCompiler.write_bytes
      ~MaskCompiler.write_double
      ~MaskCompiler.write_doubles
      ~MaskCompiler.write_int16
      ~MaskCompiler.write_int32
      ~MaskCompiler.write_str
      ~MaskCompiler.write_str_with_len
      ~MaskCompiler.write_uint16
      ~MaskCompiler.write_uint32
      ~MaskCompiler.write_uint8
      ~MaskCompiler.write_value
   
   

   
   
   